@@ -6,6 +6,7 @@ from typing import List, Any, Tuple
 
 import redis
 
+
 if redis.VERSION >= (5, 0):
     from redis.parsers import BaseParser
 else:
@@ -39,6 +40,7 @@ def bin_reverse(x, bits_count):
 
 
 class BaseFakeSocket:
+    ACCEPTED_COMMANDS_WHILE_PUBSUB = {'ping', 'subscribe', 'unsubscribe', 'psubscribe', 'punsubscribe', 'quit', }
     _connection_error_class = redis.ConnectionError
 
     def __init__(self, server, db, *args, **kwargs):
@@ -141,21 +143,14 @@ class BaseFakeSocket:
         command_items = {}
         try:
             ret = sig.apply(args, self._db, self.version)
+            if from_script and msgs.FLAG_NO_SCRIPT in sig.flags:
+                raise SimpleError(msgs.COMMAND_IN_SCRIPT_MSG)
+            if self._pubsub and sig.name not in BaseFakeSocket.ACCEPTED_COMMANDS_WHILE_PUBSUB:
+                raise SimpleError(msgs.BAD_COMMAND_IN_PUBSUB_MSG)
             if len(ret) == 1:
                 result = ret[0]
             else:
                 args, command_items = ret
-                if from_script and msgs.FLAG_NO_SCRIPT in sig.flags:
-                    raise SimpleError(msgs.COMMAND_IN_SCRIPT_MSG)
-                if self._pubsub and sig.name not in [
-                    'ping',
-                    'subscribe',
-                    'unsubscribe',
-                    'psubscribe',
-                    'punsubscribe',
-                    'quit'
-                ]:
-                    raise SimpleError(msgs.BAD_COMMAND_IN_PUBSUB_MSG)
                 result = func(*args)
                 assert valid_response_type(result)
         except SimpleError as exc:
@@ -336,11 +331,11 @@ class BaseFakeSocket:
             return int(round((key.expireat - self._db.time) * scale))
 
     def _encodefloat(self, value, humanfriendly):
-        if self.version >= 7:
+        if self.version >= (7,):
             value = 0 + value
         return Float.encode(value, humanfriendly)
 
     def _encodeint(self, value):
-        if self.version >= 7:
+        if self.version >= (7,):
             value = 0 + value
         return Int.encode(value)
