@@ -7,7 +7,7 @@ from ._helpers import SimpleError, null_terminate
 
 def _count_params(s: str):
     res = 0
-    while s[res] in '.+*~':
+    while res < len(s) and s[res] in '.+*~':
         res += 1
     return res
 
@@ -33,6 +33,7 @@ def extract_args(
         expected: Tuple[str, ...],
         error_on_unexpected: bool = True,
         left_from_first_unexpected: bool = True,
+        exception=None
 ) -> Tuple[List, List]:
     """Parse argument values
 
@@ -77,12 +78,11 @@ def extract_args(
         for (i, k) in enumerate(expected)
     }
 
-    def _parse_params(
-            key: str,
-            ind: int,
-            actual_args: Tuple[bytes, ...]) -> Tuple[Any, int]:
-        """
-        Parse an argument from actual args.
+    def _parse_params(key: str, ind: int, actual_args: Tuple[bytes, ...]) -> Tuple[Any, int]:
+        """Parse an argument from actual args.
+        :param key: argument name to parse
+        :param ind: index of argument in actual_args
+        :param actual_args: actual args
         """
         pos, expected_following = args_info[key]
         argument_name = expected[pos]
@@ -135,7 +135,10 @@ def extract_args(
 
         if not found:
             if error_on_unexpected:
-                raise SimpleError(msgs.SYNTAX_ERROR_MSG)
+                raise (
+                    SimpleError(msgs.SYNTAX_ERROR_MSG)
+                    if exception is None
+                    else SimpleError(exception.format(actual_args[i])))
             if left_from_first_unexpected:
                 return results, actual_args[i:]
             left_args.append(actual_args[i])
