@@ -5,6 +5,7 @@ Unlike _helpers.py, here the methods should be used only in mixins.
 import functools
 import math
 import re
+from typing import Tuple, Union
 
 from . import _msgs as msgs
 from ._helpers import null_terminate, SimpleError, SimpleString
@@ -250,7 +251,7 @@ class AfterAny:
 class ScoreTest:
     """Argument converter for sorted set score endpoints."""
 
-    def __init__(self, value, exclusive=False, bytes_val=None):
+    def __init__(self, value: float, exclusive: bool = False, bytes_val: bytes = None):
         self.value = value
         self.exclusive = exclusive
         self.bytes_val = bytes_val
@@ -288,12 +289,12 @@ class ScoreTest:
 class StringTest:
     """Argument converter for sorted set LEX endpoints."""
 
-    def __init__(self, value, exclusive):
+    def __init__(self, value: Union[bytes, BeforeAny, AfterAny], exclusive: bool):
         self.value = value
         self.exclusive = exclusive
 
     @classmethod
-    def decode(cls, value):
+    def decode(cls, value: bytes) -> 'StringTest':
         if value == b'-':
             return cls(BeforeAny(), True)
         elif value == b'+':
@@ -305,21 +306,32 @@ class StringTest:
         else:
             raise SimpleError(msgs.INVALID_MIN_MAX_STR_MSG)
 
+    def to_scoretest(self, zset: ZSet):
+        if isinstance(self.value, BeforeAny):
+            return ScoreTest(float('-inf'), False)
+        if isinstance(self.value, AfterAny):
+            return ScoreTest(float('inf'), False)
+        return ScoreTest(zset.get(self.value, None), self.exclusive)
+
 
 class Signature:
-    def __init__(self, name, func_name, fixed, repeat=(), flags=""):
+    def __init__(self, name, func_name, fixed, repeat=(), args=(), flags=""):
         self.name = name
         self.func_name = func_name
         self.fixed = fixed
         self.repeat = repeat
         self.flags = set(flags)
+        self.command_args = args
 
-    def check_arity(self, args, version):
+    def check_arity(self, args, version: Tuple[int]):
         if len(args) != len(self.fixed):
             delta = len(args) - len(self.fixed)
             if delta < 0 or not self.repeat:
                 msg = msgs.WRONG_ARGS_MSG6.format(self.name)
                 raise SimpleError(msg)
+            if delta % len(self.repeat) != 0:
+                msg = msgs.WRONG_ARGS_MSG7 if version >= (7,) else msgs.WRONG_ARGS_MSG6.format(self.name)
+                raise SimpleError(msg)
 
     def apply(self, args, db, version):
         """Returns a tuple, which is either:
@@ -327,11 +339,6 @@ class Signature:
         - a single containing a short-circuit return value
         """
         self.check_arity(args, version)
-        if self.repeat:
-            delta = len(args) - len(self.fixed)
-            if delta % len(self.repeat) != 0:
-                msg = msgs.WRONG_ARGS_MSG7 if version >= 7 else msgs.WRONG_ARGS_MSG6.format(self.name)
-                raise SimpleError(msg)
 
         types = list(self.fixed)
         for i in range(len(args) - len(types)):
@@ -352,12 +359,14 @@ class Signature:
             if isinstance(type_, Key):
                 item = db.get(arg)
                 default = None
-                if type_.type_ is not None:
-                    if item is not None and type(item.value) != type_.type_:
-                        raise SimpleError(msgs.WRONGTYPE_MSG)
-                    if item is None:
-                        if type_.type_ is not bytes:
-                            default = type_.type_()
+                if (type_.type_ is not None
+                        and item is not None
+                        and type(item.value) != type_.type_):
+                    raise SimpleError(msgs.WRONGTYPE_MSG)
+                if (type_.type_ is not None
+                        and item is None
+                        and type_.type_ is not bytes):
+                    default = type_.type_()
                 args[i] = CommandItem(arg, db, item, default=default)
                 command_items.append(args[i])
 
